@@ -3,7 +3,7 @@
 from . import (
     lattice,
     package_info,
-    random,
+    random_lattice,
     utils,
     visualization,
     function_iteration,
@@ -11,6 +11,7 @@ from . import (
 )
 
 # Quick access for classes and functions
+from .utils.random_state import AL_random as random
 from .package_info import (
     github,)
 from .lattice.lattice import (
@@ -20,9 +21,8 @@ from .lattice.lattice import (
 )
 from .lattice_iteration import (
     iter_all_lattices,)
-from .random.random_lattice import (
+from .random_lattice.random_lattice import (
     random_lattice,
     random_poset,
 )
-
 from .visualization.gui import new_visualizer
